@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2011-2018, Intel Corporation
+* Copyright (c) 2011-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -29,11 +29,13 @@
 #include "codechal_decode_mpeg2.h"
 #include "codechal_secure_decode_interface.h"
 #include "codechal_mmc_decode_mpeg2.h"
+#include "hal_oca_interface.h"
 #if USE_CODECHAL_DEBUG_TOOL
 #include <sstream>
 #include <fstream>
 #include "codechal_debug.h"
 #endif
+#include "mos_os_cp_interface_specific.h"
 
 #define CODECHAL_DECODE_MPEG2_IDCTBLOCK_SIZE   64
 
@@ -218,10 +220,13 @@ MOS_STATUS CodechalDecodeMpeg2::CopyDataSurface(
             "Failed to allocate copied residual data buffer.");
     }
 
-    // initialize lock flags
-    MOS_LOCK_PARAMS lockFlagsWriteOnly;
-    MOS_ZeroMemory(&lockFlagsWriteOnly, sizeof(MOS_LOCK_PARAMS));
-    lockFlagsWriteOnly.WriteOnly = 1;
+    if ((m_nextCopiedDataOffset + dataSize) > m_copiedDataBufferSize)
+    {
+        CODECHAL_DECODE_ASSERTMESSAGE("Copied data buffer is not large enough.");
+
+        m_slicesInvalid = true;
+        return MOS_STATUS_UNKNOWN;
+    }
 
     uint32_t size = MOS_ALIGN_CEIL(dataSize, 16); // 16 byte aligned
 
@@ -245,14 +250,6 @@ MOS_STATUS CodechalDecodeMpeg2::CopyDataSurface(
         return MOS_STATUS_SUCCESS;
     }
 
-    if ((m_nextCopiedDataOffset + dataSize) > m_copiedDataBufferSize)
-    {
-        CODECHAL_DECODE_ASSERTMESSAGE("Copied data buffer is not large enough.");
-
-        m_slicesInvalid = true;
-        return MOS_STATUS_UNKNOWN;
-    }
-
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnSetGpuContext(
         m_osInterface,
         m_videoContextForWa));
@@ -367,9 +364,9 @@ MOS_STATUS CodechalDecodeMpeg2::AllocateResources ()
         m_osInterface,
         &m_resSyncObjectVideoContextInUse));
 
-    CodecHalAllocateDataList(
+    CODECHAL_DECODE_CHK_STATUS_RETURN(CodecHalAllocateDataList(
         m_mpeg2RefList,
-        CODECHAL_NUM_UNCOMPRESSED_SURFACE_MPEG2);
+        CODECHAL_NUM_UNCOMPRESSED_SURFACE_MPEG2));
 
     for (uint32_t i = 0; i < CODECHAL_NUM_UNCOMPRESSED_SURFACE_MPEG2; i++)
     {
@@ -550,7 +547,7 @@ MOS_STATUS CodechalDecodeMpeg2::SetFrameStates ()
 
     MOS_ZeroMemory(m_vldSliceRecord, (m_numSlices * sizeof(CODECHAL_VLD_SLICE_RECORD)));
 
-    if (m_firstExecuteCall)
+    if (IsFirstExecuteCall())
     {
         CODECHAL_DECODE_CHK_STATUS_MESSAGE_RETURN(InitializeBeginFrame(),
             "Initial Beginframe in CodecHal failed.");
@@ -738,6 +735,9 @@ MOS_STATUS CodechalDecodeMpeg2::DecodeStateLevel()
     MOS_COMMAND_BUFFER cmdBuffer;
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnGetCommandBuffer(m_osInterface, &cmdBuffer, 0));
 
+    auto mmioRegisters = m_hwInterface->GetMfxInterface()->GetMmioRegisters(m_vdboxIndex);
+    HalOcaInterface::On1stLevelBBStart(cmdBuffer, *m_osInterface->pOsContext, m_osInterface->CurrentGpuContextHandle, *m_miInterface, *mmioRegisters);
+
     MHW_VDBOX_PIPE_MODE_SELECT_PARAMS pipeModeSelectParams;
     pipeModeSelectParams.Mode                  = m_mode;
     pipeModeSelectParams.bStreamOutEnabled     = m_streamOutEnabled;
@@ -760,7 +760,9 @@ MOS_STATUS CodechalDecodeMpeg2::DecodeStateLevel()
         pipeBufAddrParams.psPreDeblockSurface = &m_destSurface;
     }
 
+#ifdef _MMC_SUPPORTED
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_mmc->SetPipeBufAddr(&pipeBufAddrParams));
+#endif
 
     // when there is not a forward or backward reference,
     // the index is set to the destination frame index
@@ -821,7 +823,9 @@ MOS_STATUS CodechalDecodeMpeg2::DecodeStateLevel()
             &(m_streamOutBuffer[m_streamOutCurrBufIdx]);
     }
 
+#ifdef _MMC_SUPPORTED
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_mmc->CheckReferenceList(&pipeBufAddrParams));
+#endif
 
     CODECHAL_DEBUG_TOOL(
         for (uint32_t i = 0; i < CODEC_MAX_NUM_REF_FRAME_NON_AVC; i++)
@@ -841,7 +845,7 @@ MOS_STATUS CodechalDecodeMpeg2::DecodeStateLevel()
                 std::string refSurfName      = "RefSurf" + std::to_string(static_cast<uint32_t>(m_debugInterface->m_refIndex));
                 CODECHAL_DECODE_CHK_STATUS_RETURN(m_debugInterface->DumpYUVSurface(
                     &dstSurface,
-                    CodechalDbgAttr::attrReferenceSurfaces,
+                    CodechalDbgAttr::attrDecodeReferenceSurfaces,
                     refSurfName.data()));
             }
         }
@@ -1173,6 +1177,8 @@ MOS_STATUS CodechalDecodeMpeg2::SliceLevel()
 
         CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnEngineWait(m_osInterface, &syncParams));
 
+        HalOcaInterface::On1stLevelBBEnd(cmdBuffer, *m_osInterface);
+
         CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnSubmitCommandBuffer(
             m_osInterface,
             &cmdBuffer,
@@ -1608,6 +1614,8 @@ MOS_STATUS CodechalDecodeMpeg2::MacroblockLevel()
 
         CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnEngineWait(m_osInterface, &syncParams));
 
+        HalOcaInterface::On1stLevelBBEnd(cmdBuffer, *m_osInterface);
+
         CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnSubmitCommandBuffer(
             m_osInterface,
             &cmdBuffer,
@@ -1708,6 +1716,10 @@ CodechalDecodeMpeg2::CodechalDecodeMpeg2 (
     MOS_ZeroMemory(&m_resSyncObjectWaContextInUse, sizeof(m_resSyncObjectWaContextInUse));
     MOS_ZeroMemory(&m_resSyncObjectVideoContextInUse, sizeof(m_resSyncObjectVideoContextInUse));
     MOS_ZeroMemory(&m_savedMpeg2MbParam, sizeof(m_savedMpeg2MbParam));
+#if (_DEBUG || _RELEASE_INTERNAL)
+    m_reportFrameCrc = true;
+#endif
+    m_hwInterface = hwInterface;
 }
 
 #if USE_CODECHAL_DEBUG_TOOL
