@@ -70,7 +70,7 @@ DecodePipeline::DecodePipeline(
 
 MOS_STATUS DecodePipeline::CreateStatusReport()
 {
-    m_statusReport = MOS_New(DecodeStatusReport, m_allocator, true);
+    m_statusReport = MOS_New(DecodeStatusReport, m_allocator, true, m_osInterface);
     DECODE_CHK_NULL(m_statusReport);
     DECODE_CHK_STATUS(m_statusReport->Create());
 
@@ -153,7 +153,9 @@ MOS_STATUS DecodePipeline::Initialize(void *settings)
     DECODE_CHK_NULL(settings);
 
     DECODE_CHK_STATUS(MediaPipeline::InitPlatform());
-    DECODE_CHK_STATUS(MediaPipeline::CreateMediaCopy());
+    DECODE_CHK_STATUS(MediaPipeline::CreateMediaCopyWrapper());
+    DECODE_CHK_NULL(m_mediaCopyWrapper);
+    m_mediaCopyWrapper->CreateMediaCopyState();
 
     DECODE_CHK_NULL(m_waTable);
 
@@ -161,14 +163,14 @@ MOS_STATUS DecodePipeline::Initialize(void *settings)
     DECODE_CHK_NULL(m_hwInterface);
     DECODE_CHK_STATUS(m_hwInterface->Initialize(codecSettings));
 
-    if (m_mediaCopy == nullptr)
+    if (m_mediaCopyWrapper->MediaCopyStateIsNull())
     {
-        m_mediaCopy = m_hwInterface->CreateMediaCopy(m_osInterface);
+        m_mediaCopyWrapper->SetMediaCopyState(m_hwInterface->CreateMediaCopy(m_osInterface));
     }
 
 #if USE_CODECHAL_DEBUG_TOOL
     DECODE_CHK_NULL(m_debugInterface);
-    DECODE_CHK_STATUS(m_debugInterface->SetFastDumpConfig(m_mediaCopy));
+    DECODE_CHK_STATUS(m_debugInterface->SetFastDumpConfig(m_mediaCopyWrapper->GetMediaCopyState()));
 #endif
 
     m_mediaContext = MOS_New(MediaContext, scalabilityDecoder, m_hwInterface, m_osInterface);
