@@ -26,9 +26,10 @@
 //!
 
 #include "vp_csc_filter.h"
-#include "vp_vebox_cmd_packet.h"
+#include "vp_vebox_cmd_packet_base.h"
 #include "hw_filter.h"
 #include "sw_filter_pipe.h"
+#include "vp_hal_ddi_utils.h"
 
 namespace vp {
 
@@ -177,6 +178,40 @@ VPHAL_CSPACE GetSfcInputColorSpace(VP_EXECUTE_CAPS &executeCaps, VPHAL_CSPACE in
     return inputColorSpace;
 }
 
+bool VpCscFilter::IsDitheringNeeded(MOS_FORMAT formatInput, MOS_FORMAT formatOutput)
+{
+    uint32_t inputBitDepth = VpHalDDIUtils::GetSurfaceBitDepth(formatInput);
+    if (inputBitDepth == 0)
+    {
+        VP_PUBLIC_ASSERTMESSAGE("Unknown Input format %d for bit depth, return false", formatInput);
+        return false;
+    }
+    uint32_t outputBitDepth = VpHalDDIUtils::GetSurfaceBitDepth(formatOutput);
+    if (outputBitDepth == 0)
+    {
+        VP_PUBLIC_ASSERTMESSAGE("Unknown Output format %d for bit depth, return false", formatOutput);
+        return false;
+    }
+    if (inputBitDepth > outputBitDepth)
+    {
+        VP_RENDER_NORMALMESSAGE("inputFormat = %d, inputBitDepth = %d, outputFormat = %d, outputBitDepth = %d, return true",
+            formatInput,
+            inputBitDepth,
+            formatOutput,
+            outputBitDepth);
+        return true;
+    }
+    else
+    {
+        VP_RENDER_NORMALMESSAGE("inputFormat = %d, inputBitDepth = %d, outputFormat = %d, outputBitDepth = %d, return false",
+            formatInput,
+            inputBitDepth,
+            formatOutput,
+            outputBitDepth);
+        return false;
+    }
+}
+
 MOS_STATUS VpCscFilter::CalculateSfcEngineParams()
 {
     VP_FUNC_CALL();
@@ -212,6 +247,10 @@ MOS_STATUS VpCscFilter::CalculateSfcEngineParams()
     }
 
     m_cscParams.input.colorSpace    = m_cscParams.input.colorSpace;
+
+    // IsDitheringNeeded should be called before input format being updated by GetSfcInputFormat
+    m_sfcCSCParams->isDitheringNeeded = IsDitheringNeeded(m_cscParams.formatInput, m_cscParams.formatOutput);
+
     m_sfcCSCParams->inputColorSpace = GetSfcInputColorSpace(m_executeCaps, m_cscParams.input.colorSpace, m_cscParams.output.colorSpace);
 
     m_cscParams.formatInput         = GetSfcInputFormat(m_executeCaps, m_cscParams.formatInput, m_cscParams.output.colorSpace);
@@ -302,7 +341,7 @@ MOS_STATUS VpCscFilter::SetSfcChromaParams(
 
     if (vpExecuteCaps.bVebox)
     {
-        if (VpHal_GetSurfaceColorPack(m_sfcCSCParams->inputFormat) == VPHAL_COLORPACK_444)
+        if (VpHalDDIUtils::GetSurfaceColorPack(m_sfcCSCParams->inputFormat) == VPHAL_COLORPACK_444)
         {
             m_sfcCSCParams->b8tapChromafiltering = true;
         }
@@ -339,7 +378,14 @@ MOS_STATUS VpCscFilter::SetVeboxCUSChromaParams(VP_EXECUTE_CAPS vpExecuteCaps)
         (vpExecuteCaps.b3DlutOutput && !vpExecuteCaps.bHDR3DLUT);
     bool bDIEnabled      = vpExecuteCaps.bDI;
 
-    srcColorPack = VpHal_GetSurfaceColorPack(m_cscParams.formatInput);
+    if (Format_None != m_cscParams.formatforCUS)
+    {
+        srcColorPack = VpHalDDIUtils::GetSurfaceColorPack(m_cscParams.formatforCUS);
+    }
+    else
+    {
+        srcColorPack = VpHalDDIUtils::GetSurfaceColorPack(m_cscParams.formatInput);
+    }
 
     // Init CUS as disabled
     m_veboxCSCParams->bypassCUS = true;
@@ -486,7 +532,7 @@ MOS_STATUS VpCscFilter::SetVeboxCDSChromaParams(VP_EXECUTE_CAPS vpExecuteCaps)
 
     bool bNeedDownSampling = false;
 
-    VPHAL_COLORPACK dstColorPack = VpHal_GetSurfaceColorPack(m_cscParams.formatOutput);
+    VPHAL_COLORPACK dstColorPack = VpHalDDIUtils::GetSurfaceColorPack(m_cscParams.formatOutput);
 
     // Only VEBOX output, we use VEO to do downsampling.
     // Else, we use SFC/FC path to do downscaling.
@@ -497,7 +543,7 @@ MOS_STATUS VpCscFilter::SetVeboxCDSChromaParams(VP_EXECUTE_CAPS vpExecuteCaps)
     }
     else
     {
-        bNeedDownSampling = vpExecuteCaps.bVebox && !vpExecuteCaps.bSFC;
+        bNeedDownSampling = vpExecuteCaps.bVebox && !vpExecuteCaps.bSFC && !vpExecuteCaps.bForceCscToRender;
     }
 
     // Init as CDS disabled
@@ -605,7 +651,7 @@ MOS_STATUS VpCscFilter::UpdateChromaSiting(VP_EXECUTE_CAPS vpExecuteCaps)
     {
         m_cscParams.input.chromaSiting = (CHROMA_SITING_HORZ_LEFT | CHROMA_SITING_VERT_CENTER);
     }
-    switch (VpHal_GetSurfaceColorPack(m_cscParams.formatInput))
+    switch (VpHalDDIUtils::GetSurfaceColorPack(m_cscParams.formatInput))
     {
     case VPHAL_COLORPACK_422:
         m_cscParams.input.chromaSiting = (m_cscParams.input.chromaSiting & 0x7) | CHROMA_SITING_VERT_TOP;
@@ -621,7 +667,7 @@ MOS_STATUS VpCscFilter::UpdateChromaSiting(VP_EXECUTE_CAPS vpExecuteCaps)
     {
         m_cscParams.output.chromaSiting = (CHROMA_SITING_HORZ_LEFT | CHROMA_SITING_VERT_CENTER);
     }
-    switch (VpHal_GetSurfaceColorPack(m_cscParams.formatOutput))
+    switch (VpHalDDIUtils::GetSurfaceColorPack(m_cscParams.formatOutput))
     {
     case VPHAL_COLORPACK_422:
         m_cscParams.output.chromaSiting = (m_cscParams.output.chromaSiting & 0x7) | CHROMA_SITING_VERT_TOP;
@@ -643,8 +689,8 @@ bool VpCscFilter::IsChromaUpSamplingNeeded()
     bool                  bChromaUpSampling = false;
     VPHAL_COLORPACK       srcColorPack, dstColorPack;
 
-    srcColorPack = VpHal_GetSurfaceColorPack(m_cscParams.formatInput);
-    dstColorPack = VpHal_GetSurfaceColorPack(m_cscParams.formatOutput);
+    srcColorPack = VpHalDDIUtils::GetSurfaceColorPack(m_cscParams.formatInput);
+    dstColorPack = VpHalDDIUtils::GetSurfaceColorPack(m_cscParams.formatOutput);
 
     if ((srcColorPack == VPHAL_COLORPACK_420 &&
         (dstColorPack == VPHAL_COLORPACK_422 || dstColorPack == VPHAL_COLORPACK_444)) ||
@@ -653,6 +699,9 @@ bool VpCscFilter::IsChromaUpSamplingNeeded()
         bChromaUpSampling = true;
     }
 
+    VP_PUBLIC_NORMALMESSAGE("formatInput %d, formatOutput %d, srcColorPack %d, dstColorPack %d, bChromaUpSampling %d",
+        m_cscParams.formatInput, m_cscParams.formatOutput, srcColorPack, dstColorPack, bChromaUpSampling ? 1 : 0);
+
     return bChromaUpSampling;
 }
 
@@ -728,22 +777,25 @@ VpSfcCscParameter::VpSfcCscParameter(PVP_MHWINTERFACE pHwInterface, PacketParamF
 }
 VpSfcCscParameter::~VpSfcCscParameter() {}
 
-bool VpSfcCscParameter::SetPacketParam(VpCmdPacket *pPacket)
+bool VpSfcCscParameter::SetPacketParam(VpCmdPacket *_packet)
 {
     VP_FUNC_CALL();
 
-    VpVeboxCmdPacket *pVeboxPacket = dynamic_cast<VpVeboxCmdPacket *>(pPacket);
-    if (nullptr == pVeboxPacket)
+    SFC_CSC_PARAMS *params = m_CscFilter.GetSfcParams();
+    if (nullptr == params)
     {
+        VP_PUBLIC_ASSERTMESSAGE("Failed to get sfc csc params");
         return false;
     }
 
-    SFC_CSC_PARAMS *pParams = m_CscFilter.GetSfcParams();
-    if (nullptr == pParams)
+    VpVeboxCmdPacketBase *packet = dynamic_cast<VpVeboxCmdPacketBase *>(_packet);
+    if (packet)
     {
-        return false;
+        return MOS_SUCCEEDED(packet->SetSfcCSCParams(params));
     }
-    return MOS_SUCCEEDED(pVeboxPacket->SetSfcCSCParams(pParams));
+
+    VP_PUBLIC_ASSERTMESSAGE("Invalid packet for sfc csc");
+    return false;
 }
 
 MOS_STATUS VpSfcCscParameter::Initialize(HW_FILTER_CSC_PARAM &params)
@@ -925,18 +977,21 @@ bool VpVeboxCscParameter::SetPacketParam(VpCmdPacket* pPacket)
 {
     VP_FUNC_CALL();
 
-    VpVeboxCmdPacket* pVeboxPacket = dynamic_cast<VpVeboxCmdPacket*>(pPacket);
-    if (nullptr == pVeboxPacket)
+    VEBOX_CSC_PARAMS *params = m_CscFilter.GetVeboxParams();
+    if (nullptr == params)
     {
+        VP_PUBLIC_ASSERTMESSAGE("Failed to get vebox be csc params");
         return false;
     }
 
-    VEBOX_CSC_PARAMS* pParams = m_CscFilter.GetVeboxParams();
-    if (nullptr == pParams)
+    VpVeboxCmdPacketBase *packet = dynamic_cast<VpVeboxCmdPacketBase *>(pPacket);
+    if (packet)
     {
-        return false;
+        return MOS_SUCCEEDED(packet->SetVeboxBeCSCParams(params));
     }
-    return MOS_SUCCEEDED(pVeboxPacket->SetVeboxBeCSCParams(pParams));
+
+    VP_PUBLIC_ASSERTMESSAGE("Invalid packet for vebox be csc");
+    return false;
 }
 MOS_STATUS VpVeboxCscParameter::Initialize(HW_FILTER_CSC_PARAM& params)
 {
@@ -1019,7 +1074,7 @@ MOS_STATUS PolicyVeboxCscHandler::UpdateFeaturePipe(VP_EXECUTE_CAPS caps, SwFilt
     SwFilterCsc *featureCsc = dynamic_cast<SwFilterCsc *>(&feature);
     VP_PUBLIC_CHK_NULL_RETURN(featureCsc);
 
-    if (caps.bForceCscToRender)
+    if (!featureCsc->GetFilterEngineCaps().VeboxNeeded || caps.bForceCscToRender)
     {
         SwFilterCsc *filter2ndPass = featureCsc;
         SwFilterCsc *filter1ndPass = (SwFilterCsc *)feature.Clone();
@@ -1028,6 +1083,13 @@ MOS_STATUS PolicyVeboxCscHandler::UpdateFeaturePipe(VP_EXECUTE_CAPS caps, SwFilt
         VP_PUBLIC_CHK_NULL_RETURN(filter2ndPass);
 
         filter1ndPass->GetFilterEngineCaps() = filter2ndPass->GetFilterEngineCaps();
+
+        if (!filter1ndPass->GetFilterEngineCaps().VeboxNeeded)
+        {
+            VP_PUBLIC_NORMALMESSAGE("VeboxNeeded being false. Just do chroma sitting in current pass");
+            filter1ndPass->GetFilterEngineCaps().VeboxNeeded = 1;
+        }
+
         filter1ndPass->SetFeatureType(filter2ndPass->GetFeatureType());
 
         FeatureParamCsc &params2ndPass = filter2ndPass->GetSwFilterParams();
@@ -1047,14 +1109,24 @@ MOS_STATUS PolicyVeboxCscHandler::UpdateFeaturePipe(VP_EXECUTE_CAPS caps, SwFilt
         filter2ndPass->SetFeatureType(FeatureTypeCsc);
         filter2ndPass->GetFilterEngineCaps().usedForNextPass = 1;
 
-        // Switch to render engine for csc filter.
-        VP_PUBLIC_NORMALMESSAGE("Force csc to render case. VeboxNeeded: %d -> 0, RenderNeeded: %d -> 1",
-            filter2ndPass->GetFilterEngineCaps().VeboxNeeded,
-            filter2ndPass->GetFilterEngineCaps().RenderNeeded);
-        filter2ndPass->GetFilterEngineCaps().bEnabled     = 1;
-        filter2ndPass->GetFilterEngineCaps().VeboxNeeded  = 0;
-        filter2ndPass->GetFilterEngineCaps().RenderNeeded = 1;
-        filter2ndPass->GetFilterEngineCaps().fcSupported  = 1;
+        if (caps.bForceCscToRender)
+        {
+            // Switch to render engine for csc filter.
+            VP_PUBLIC_NORMALMESSAGE("Force csc to render case. VeboxNeeded: %d -> 0, RenderNeeded: %d -> 1",
+                filter2ndPass->GetFilterEngineCaps().VeboxNeeded,
+                filter2ndPass->GetFilterEngineCaps().RenderNeeded);
+            filter2ndPass->GetFilterEngineCaps().bEnabled     = 1;
+            filter2ndPass->GetFilterEngineCaps().VeboxNeeded  = 0;
+            filter2ndPass->GetFilterEngineCaps().RenderNeeded = 1;
+            filter2ndPass->GetFilterEngineCaps().fcSupported  = 1;
+        }
+        else
+        {
+            VP_PUBLIC_NORMALMESSAGE("VeboxNeeded being false.Keep engine caps for next pass no change. enable %d, SfcNeeded %d, RenderNeeded %d",
+                filter2ndPass->GetFilterEngineCaps().bEnabled,
+                filter2ndPass->GetFilterEngineCaps().SfcNeeded,
+                filter2ndPass->GetFilterEngineCaps().RenderNeeded);
+        }
 
         executePipe.AddSwFilterUnordered(filter1ndPass, isInputPipe, index);
     }
